@@ -3,21 +3,22 @@ Main interface for iotsecuretunneling service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iotsecuretunneling import (
+    from mypy_boto3_iotsecuretunneling import (
         Client,
         IoTSecureTunnelingClient,
-        )
+    )
 
     session = boto3.Session()
 
     client: IoTSecureTunnelingClient = boto3.client("iotsecuretunneling")
     session_client: IoTSecureTunnelingClient = session.client("iotsecuretunneling")
+    ```
 """
-from mypy_boto3_iotsecuretunneling.client import (
-    IoTSecureTunnelingClient as Client,
-    IoTSecureTunnelingClient,
-)
+from mypy_boto3_iotsecuretunneling.client import IoTSecureTunnelingClient
+
+Client = IoTSecureTunnelingClient
 
 
 __all__ = ("Client", "IoTSecureTunnelingClient")
